@@ -22,7 +22,7 @@ sub {
         'libzmq.so.3 soname gives 3.x/4.x version';
 
     throws_ok { zmq_version('libzmq.so.X') }
-        qr/libzmq.so.X: cannot open shared object file/,
+        qr/Could not find zmq_version in 'libzmq\.so\.X'/,
         'bad soname throws error';
 
 };
@@ -45,12 +45,12 @@ sub
         'libzmq.so.3 soname gives 3.x/4.x version';
 
     throws_ok { ZMQ::FFI->new(soname => 'libzmq.so.X') }
-        qr/libzmq\.so\.X: cannot open shared object file/,
+        qr/Failed to load 'libzmq\.so\.X'/,
         'bad soname throws error';
 
 
-    my $v2_endpoint = "ipc:///tmp/zmq-ffi-ctx2-$$";
-    my $v3_endpoint = "ipc:///tmp/zmq-ffi-ctx3-$$";
+    my $v2_endpoint = "ipc://zmq-ffi-ctx2-$$";
+    my $v3_endpoint = "ipc://zmq-ffi-ctx3-$$";
 
     my $s_v2_req = $ctx_v2->socket(ZMQ_REQ);
     $s_v2_req->connect($v2_endpoint);
